@@ -9,9 +9,23 @@
 
 #include "pdbFatItem.h"
 
+/** \brief A class to define the namespace.
+	*
+	*	This class records the members of each namespace.
+	**/
 class pdbNamespace : public pdbFatItem {
 public:
+  
+  /** pdbNamespace constructor
+  	*
+		* \param id unique idenfier.
+		**/
   pdbNamespace(int id);
+  /** pdbNamespace constructor
+  	*
+		* \param name this namespace's name.
+		* \param id unique idenfier.
+		**/
   pdbNamespace(const string& name, int id);
 
   virtual const char *desc() const;
@@ -22,7 +36,9 @@ public:
 
   typedef vector<pdbItem *> memvec;
 
+	/** A vector of members of this namespace. **/
   const memvec& members() const;
+	/** Pointer to alias namespace. **/
   const pdbNamespace* isAlias() const;
 
   void addMember(pdbItem* item);
