@@ -9,9 +9,18 @@
 
 #include "pdbItem.h"
 
+/** \brief A class to represent C/C++ enumuations. 
+	*
+	* pdbEnum describes one element of an C / C++ enumeration type by its name
+	* (identifier) and the corresponding integer value.
+	**/
 class pdbEnum {
 public:
-  pdbEnum(const char* id, int val);
+  /** A constructor 
+		*
+		* \param *id unique idenifier.
+		* \param val integer value of the enumuation. **/
+	pdbEnum(const char* id, int val);
   const string& id() const;
   int val() const;
 private:
@@ -19,10 +28,22 @@ private:
   int    v;
 };
 
+/** \brief A class to represent Fortran bounds.
+	*
+	* pdbBounds is used to describe the bounds of one dimension of a Fortran
+	* array. 
+	**/
 class pdbBounds {
 public:
-  pdbBounds(int low, int upp);
-  int lower() const;
+  /** A constructor
+		*
+		* \param low lower bound.
+		* \param upp upper bound.
+		**/
+	pdbBounds(int low, int upp);
+  /** lower bound. **/
+	int lower() const;
+	/** upper bound. **/
   int upper() const;
   static const int UNKNOWN;
 private:
@@ -30,6 +51,12 @@ private:
   int up;
 };
 
+/** \brief A class for arguments for routines.
+	*
+	* This class describes arguments given to pbdRoutines. It hold information
+	* about these arguments and how they are given to Routines as parameters.
+	**/
+	
 class pdbArg : public pdbLoc {
 public:
   enum arg_t { ARG_NA=0, ARG_IN=1, ARG_OUT=2, ARG_INOUT=3,
@@ -37,12 +64,17 @@ public:
 
   pdbArg(const pdbType *type, const string& name,
          pdbFile *file, int line, int col, int flags = ARG_NA);
-  const pdbType* type() const;
+  
+	/** the abstract type of the argument. **/
+	const pdbType* type() const;
+	/** the name of the argument. **/
   const string& name() const;
   bool intentIn() const;        /*f90*/
   bool intentOut() const;       /*f90*/
   bool isOptional() const;      /*f90*/
-  bool hasDefault() const;
+  /** if the argument of this routine has a default parameter for this argument.
+	 **/
+	bool hasDefault() const;
   int flags() const;
 
   void type(const pdbType *t);
@@ -58,6 +90,11 @@ private:
   int            flg;
 };
 
+/** \brief A class to contain the abstract Type information.
+	*
+	*	This class hold the information about Fortran and C/C++ types both abstract
+	*	and basic types.
+	**/
 class pdbType : public pdbItem {
 public:
   pdbType(int id);
@@ -78,10 +115,14 @@ public:
 
   static const pdbType* NULLEXCEP;
 
+	/** the abstract type of this argument. **/
   const pdbType* elementType() const;
-  float_t floatType() const;
+  /** the float type of this argument. **/
+	float_t floatType() const;
+	/** the integer type of this argument. **/
   int_t integerType() const;
-  type_t kind() const;
+  /** the kind of the type.**/
+	type_t kind() const;
   const qualvec& qualifiers() const;
   const pdbType* pointedToType() const;
   const pdbType* referencedType() const;
@@ -95,7 +136,7 @@ public:
   const pdbType* memberPointerType() const;
   const pdbClass* memberPointerClass() const;
   bool isConst() const;
-  int numElements() const;  // for C arrays and f90 characters
+  int numElements() const;  /** for C arrays and f90 characters **/
   const typevec& exceptionSpec() const;
   const enumvec& enumeration() const;
   shape_t shape() const;              /*f90*/
@@ -129,6 +170,17 @@ public:
   void addBound(int low, int high);  /*f90*/
   void isStaticArray(bool s);  /*C99*/
 
+  // UPC
+  bool isShared() const;
+  int  blockSize() const;
+  bool isRelaxed() const;
+  bool isStrict() const;
+
+  void isShared(bool s);
+  void blockSize(int b);
+  void isRelaxed(bool r);
+  void isStrict(bool s);
+
 private:
   const pdbType  *elemTy;
   float_t         fltTy;
@@ -152,6 +204,10 @@ private:
   typevec         exSpec;
   enumvec         enums;
   boundvec        bnds;
+  bool            shared;
+  int             blocksize;
+  bool            relaxed;
+  bool            strict;
 };
 
 #ifndef NO_INLINE
