@@ -143,6 +143,7 @@ void PDB::initAttrs() {
   attr["rinline"]  = RINLINE;   name[RINLINE]   = "rinline";
   attr["riselem"]  = RISELEM;   name[RISELEM]   = "riselem";
   attr["rkind"]    = RKIND;     name[RKIND]     = "rkind";
+  attr["rfprefix"] = RFPREFIX;  name[RFPREFIX]  = "rfprefix";
   attr["rlink"]    = RLINK;     name[RLINK]     = "rlink";
   attr["rrec"]     = RREC;      name[RREC]      = "rrec";
   attr["rret"]     = RRET;      name[RRET]      = "rret";
@@ -190,6 +191,11 @@ void PDB::initAttrs() {
   attr["ysigned"]  = YSIGNED;   name[YSIGNED]   = "ysigned";
   attr["ystat"]    = YSTAT;     name[YSTAT]     = "ystat";
   attr["ytref"]    = YTREF;     name[YTREF]     = "ytref";
+  // UPC support
+  attr["yshared"]    = YSHARED;    name[YSHARED]    = "yshared";
+  attr["yblocksize"] = YBLOCKSIZE; name[YBLOCKSIZE] = "yblocksize";
+  attr["yrelaxed"]   = YRELAXED;   name[YRELAXED]   = "yrelaxed";
+  attr["ystrict"]    = YSTRICT;    name[YSTRICT]    = "ystrict";
 }
 
 const char *PDB::toName(lang_t v) {
@@ -200,6 +206,7 @@ const char *PDB::toName(lang_t v) {
   case LA_FORTRAN  : return "fortran";
   case LA_JAVA     : return "java";
   case LA_MULTI    : return "multi";
+  case LA_UPC      : return "upc";
   case LA_NA       :
   default          : return "NA";
   }
@@ -212,6 +219,7 @@ PDB::lang_t PDB::toLang(const char *v) {
   if ( strcmp("fortran",  v) == 0 ) return LA_FORTRAN;
   if ( strcmp("java",     v) == 0 ) return LA_JAVA;
   if ( strcmp("multi",    v) == 0 ) return LA_MULTI;
+  if ( strcmp("upc",      v) == 0 ) return LA_UPC;
   if ( strcmp("NA",       v) == 0 ) return LA_NA;
   pdb_ERROR("Unknown language ", v);
   return LA_NA;
