@@ -8,6 +8,7 @@
 #include "pdbCRoutine.h"
 #include "pdbFRoutine.h"
 #include "pdbClass.h"
+#include <stdio.h>
 
 #ifdef NO_INLINE
 #  define inline
@@ -42,6 +43,36 @@ const char *pdbStmt::toName(stmt_t v) {
   case ST_SET_VLA_SIZE: return "set_vla_size";
   case ST_VLA_DECL    : return "vla_decl";
   case ST_VLA_DEALLOC : return "vla_dealloc";
+  case ST_FALLOCATE : return "fallocate";
+  case ST_FASSIGN : return "fassign";
+  case ST_FIO : return "fio";
+  case ST_FDO : return "fdo";
+  case ST_FDEALLOCATE : return "fdeallocate";
+  case ST_FRETURN : return "freturn";
+  case ST_FIF : return "fif";
+  case ST_FCONTINUE : return "fcontinue";
+  case ST_FSINGLE_IF : return "fsingle_if";
+  case ST_FGOTO : return "fgoto";
+  case ST_FSTOP : return "fstop";
+  case ST_FLABEL : return "flabel";
+  case ST_FEXIT: return "fexit";
+  case ST_FCYCLE : return "fcycle";
+  case ST_FARITHIF : return "farithif";
+  case ST_FENTRY : return "fentry";
+  case ST_FPAUSE : return "fpause";
+  case ST_FLABELASSIGN : return "flabelassign";
+  case ST_FPOINTERASSIGN : return "fpointerassign";
+  case ST_FSELECT : return "fselect";
+  case ST_FCASE : return "fcase";
+  case ST_FWHERE : return "fwhere";
+  case ST_FFORALL : return "fforall";
+  case ST_FCALL : return "fcall";
+  // UPC support
+  case ST_UPC_FORALL: return "upc_forall";
+  case ST_UPC_BARRIER: return "upc_barrier";
+  case ST_UPC_FENCE: return "upc_fence";
+  case ST_UPC_NOTIFY: return "upc_notify";
+  case ST_UPC_WAIT: return "upc_wait";
   case ST_NA    :
   default       : return "NA";
   }
@@ -72,6 +103,39 @@ pdbStmt::stmt_t pdbStmt::toStmt(const char *v) {
   if ( strcmp ("set_vla_size", v) == 0 ) return ST_SET_VLA_SIZE;
   if ( strcmp ("vla_decl",     v) == 0 ) return ST_VLA_DECL;
   if ( strcmp ("vla_dealloc",  v) == 0 ) return ST_VLA_DEALLOC;
+  if ( strcmp ("fallocate",   v) == 0 ) return ST_FALLOCATE;
+  if ( strcmp ("fassign",     v) == 0 ) return ST_FASSIGN;
+  if ( strcmp ("fio",         v) == 0 ) return ST_FIO;
+  if ( strcmp ("fdo",         v) == 0 ) return ST_FDO;
+  if ( strcmp ("fdeallocate", v) == 0 ) return ST_FDEALLOCATE;
+  if ( strcmp ("freturn",     v) == 0 ) return ST_FRETURN;
+  if ( strcmp ("fif",     v) == 0 ) return ST_FIF;
+  if ( strcmp ("fsingle_if",     v) == 0 ) return ST_FSINGLE_IF;
+  if ( strcmp ("fgoto",     v) == 0 ) return ST_FGOTO;
+  if ( strcmp ("fstop",     v) == 0 ) return ST_FSTOP;
+  if ( strcmp ("flabel",     v) == 0 ) return ST_FLABEL;
+  if ( strcmp ("fexit",     v) == 0 ) return ST_FEXIT;
+  if ( strcmp ("fcycle",     v) == 0 ) return ST_FCYCLE;
+  if ( strcmp ("farithif",     v) == 0 ) return ST_FARITHIF;
+  if ( strcmp ("fentry",     v) == 0 ) return ST_FENTRY;
+  if ( strcmp ("fpause",     v) == 0 ) return ST_FPAUSE;
+  if ( strcmp ("flabelassign",     v) == 0 ) return ST_FLABELASSIGN;
+  if ( strcmp ("fpointerassign",     v) == 0 ) return ST_FPOINTERASSIGN;
+  if ( strcmp ("fselect",     v) == 0 ) return ST_FSELECT;
+  if ( strcmp ("fcase",     v) == 0 ) return ST_FCASE;
+  if ( strcmp ("fwhere",     v) == 0 ) return ST_FWHERE;
+  if ( strcmp ("fforall",     v) == 0 ) return ST_FFORALL;
+  if ( strcmp ("fcall",     v) == 0 ) return ST_FCALL;
+  if ( strcmp ("fcontinue",     v) == 0 ) return ST_FCONTINUE;
+  // UPC support
+  if ( strcmp ("upc_forall",     v) == 0 ) return ST_UPC_FORALL;
+  if ( strcmp ("upc_barrier",     v) == 0 ) return ST_UPC_BARRIER;
+  if ( strcmp ("upc_fence",     v) == 0 ) return ST_UPC_FENCE;
+  if ( strcmp ("upc_notify",     v) == 0 ) return ST_UPC_NOTIFY;
+  if ( strcmp ("upc_wait",     v) == 0 ) return ST_UPC_WAIT;
+
+
+
   pdb_ERROR("Unknown statement kind ", v);
   return ST_NA;
 }
@@ -94,7 +158,12 @@ ostream& operator<<(ostream& ostr, const pdbStmt& s) {
   else if ( s.kind() == pdbStmt::ST_DECL ||
             s.kind() == pdbStmt::ST_IF   ||
             s.kind() == pdbStmt::ST_CASE ||
-	    s.kind() == pdbStmt::ST_FOR )
+	        s.kind() == pdbStmt::ST_FOR  ||
+            s.kind() == pdbStmt::ST_UPC_FORALL)
+    ostr << " NA";
+  if ((s1 = s.affinityStmt()) != NULL) 
+    ostr << " st#" << s1->id();
+  else if ( s.kind() == pdbStmt::ST_UPC_FORALL)
     ostr << " NA";
   return ostr;
 }
@@ -132,11 +201,24 @@ void pdbRoutine::process(PDB *p) {
     p->callTree()->addCallee(this, pdbItem::VI_NO, 0, 0, 0);
   }
 
+  int lastid=-1;
   // recreate PDB 2.0 return location information from statement info
   for (stmtvec::const_iterator st=statements().begin(); st!=statements().end(); ++st) {
-    if ( (*st)->kind() == pdbStmt::ST_RETURN ) {
-      const pdbLoc& loc = (*st)->stmtBegin();
-      if ( loc.file() ) addReturnLocation(loc.file(), loc.line(), loc.col());
+    if (*st == NULL) {
+      fprintf (stderr, "Error: invalid PDB file, last was st#%d\n",lastid);
+    } else {
+      lastid = (*st)->id();
+      if ( (*st)->kind() == pdbStmt::ST_RETURN || (*st)->kind() == pdbStmt::ST_FRETURN ) {
+	const pdbLoc& loc = (*st)->stmtBegin();
+	if ( loc.file() ) addReturnLocation(loc.file(), loc.line(), loc.col());
+      }
+      if ( (*st)->kind() == pdbStmt::ST_FSTOP ) {
+	const pdbLoc& loc = (*st)->stmtBegin();
+	if ( loc.file() ) {
+	  pdbFRoutine *f = dynamic_cast<pdbFRoutine *> (this);
+	  f->addStopLocation(const_cast<pdbFile*>(loc.file()), loc.line(), loc.col());
+	}
+      }
     }
   }
 
@@ -163,7 +245,7 @@ ostream& pdbRoutine::print(ostream& ostr) const {
   if ( (s = body()) ) {
     ostr << "rbody st#" << s->id() << "\n";
     for (int i=0; i<stmts.size(); ++i)
-      if ( stmts[i] ) ostr << "rstmt " << *(stmts[i]) << "\n";
+      if ( stmts[i] && stmts[i]->kind() != pdbStmt::ST_NA ) ostr << "rstmt " << *(stmts[i]) << "\n";
   } else {
     if ( firstExecStmtLocation().file() )
       ostr << "rstart " << firstExecStmtLocation() << "\n";
