@@ -298,6 +298,7 @@ namespace {
    */
   void process_fcom(vector<string>& cStmt, int sline, int scol, int ecol,
                     pdbFile* file, PDB& pdb, const string& prefix) {
+    printf ("prefix=%s\n", prefix.c_str());
     if ( prefix.size() > 1 ) {
       // directive/pragma
       if ( gen_pragmas ) {
@@ -471,7 +472,7 @@ namespace {
                 if ( line[pos] == '\"' ) { pos++; }
               }
             }
-            while ( line[pos] != '\"' );
+            while ( line[pos] != '\"' && pos < line.size());
             pos++;
 
           } else if ( line[pos] == '\'' ) {
@@ -483,7 +484,7 @@ namespace {
                 if ( line[pos] == '\'' ) { pos++; }
               }
             }
-            while ( line[pos] != '\'' );
+            while ( line[pos] != '\'' && pos < line.size() );
             pos++;
           } else {
             pos++;
@@ -548,8 +549,7 @@ namespace {
 	cend = line.size();
       } else if ( line.size() &&
         (cstart = lowline.find_first_not_of(" \t")) != string::npos &&
-	lowline[cstart] == '!' &&
-	cstart != 5 ) {
+	lowline[cstart] == '!') {
 	/*
          * free form full line comment
          */
@@ -666,7 +666,32 @@ int main(int argc, char *argv[]) {
   }
   if ( errflag ) {
     cerr << "usage: " << argv[0]
-         << " [-o outfile] [-v] [-c|-p] [-d] [-D directive] pdbfile" << endl;
+         << " [-o outfile] [-v] [-c|-p] [-d] [-D directive] pdbfile" << "\n\n";
+
+    cerr << "Scans all (non-system) source files related to a PDB file \n"
+      "for C, C++, Fortran comments, C/C++ pragmas, and Fortran\n"
+      "directives and prints out a new enhanced PDB file containing\n"
+      "this additional information.\n"
+      "\n"
+      "Options:\n\n"
+      "     -o <outfile>  Write output to file <outfile>\n\n"
+      "     -c            Only scan for comments (ignore pragmas)\n\n"
+      "     -p            Only scan for pragmas (ignore comments)\n\n"
+      "     -d            Fortran only: Consider lines with a 'D'\n"
+      "                   in the first column also as comments\n\n"
+      "     -v            Verbose mode\n\n"
+      "     -D string     Fortran only: Scan also for directives\n"
+      "                   which are marked with the sentinel 'string'.\n"
+      "                   This option can be specified several times,\n"
+      "                   once for each directive sentinel to scan for.\n"
+      "                   Case does NOT matter when specifiying 'string'.\n"
+      "                   pdbcomment recognizes OpenMP (sentinel $omp)\n"
+      "                   by default.\n\n";
+
+
+
+
+
     return 1;
   }
 
