@@ -2335,6 +2335,15 @@ static bool processFile(PDB& pdb, filenamedata* f,
 int main(int argc, char *argv[]) {
    if ( argc != 2 ) {
       cerr << "usage: " << argv[0] << " pdbfile" << endl;
+      cerr << "pdbhtml   : Produces \"htmlized\" versions of all source and header files\n"
+            "contained in the program database file <pdbfile>. It also\n"
+            "produces an HTML index of Classes, Templates, Namespaces,\n"
+            "and Functions called \"index.html\". Usage:\n\n"
+
+            "  pdbhtml <pdbfile>\n\n"
+
+            "Only works for C and C++ sources for now.";
+
       return 1;
    }
 
