@@ -29,6 +29,21 @@ int main(int argc, char *argv[]) {
   }
   if ( errflag ) {
     cerr << "usage: " << argv[0] << " [[-v] -o outfile] pdbfile..." << endl;
+    cerr << "pdbmerge  : Takes a set of program database files and merges them into one,\n"
+            "eliminating duplicate items from different files, in the process.\n"
+            "Usage:\n\n"
+
+              "pdbmerge [ [-v] -o <outfile>] <pdbfiles>...\n\n"
+
+            "-v            Verbose.\n\n"
+
+            "-o <outfile>  Write merged database to file <outfile> instead of\n"
+                          "cout.\n\n"
+
+            "Note:  Namespace definitions spread over several files are\n"
+            "not merged correctly yet.\n";
+
+    
     return 1;
   }
 
