@@ -52,7 +52,7 @@ void printStmt(ostream& ostr, const pdbStmt *s, int level) {
   else {
     ostr << pdbStmt::toName(k);
     if ( k == pdbStmt::ST_GOTO || k == pdbStmt::ST_BREAK ||
-         k == pdbStmt::ST_CONTINUE || k == pdbStmt::ST_FOR ) {
+         k == pdbStmt::ST_CONTINUE || k == pdbStmt::ST_FOR || k == pdbStmt::ST_UPC_FORALL) {
       if ( s->extraStmt() ) ostr << " -> st#" << s->extraStmt()->id();
     }
     ostr << "\n";
@@ -76,6 +76,17 @@ void printStmt(ostream& ostr, const pdbStmt *s, int level) {
     ostr << ":  ";
     ostr << setw(level*2) << "" << "}\n";
     break;
+#ifdef PDB_FORTRAN_EXTENDED_STATEMENTS_LEVEL_1
+  case pdbStmt::ST_FGOTO:
+    break; /* don't go into extraStmt for Fortran GOTO to avoid looping */
+#endif /* PDB_FORTRAN_EXTENDED_STATEMENTS_LEVEL_1 */
+#ifdef PDB_FORTRAN_EXTENDED_STATEMENTS_LEVEL_2
+  case pdbStmt::ST_FEXIT:
+  case pdbStmt::ST_FCYCLE:
+  case pdbStmt::ST_FWHERE:
+    break; /* don't go into extraStmt for Fortran EXIT to avoid looping */
+#endif /* PDB_FORTRAN_EXTENDED_STATEMENTS_LEVEL_1 */
+
   default:
     printStmt(ostr, s->extraStmt(), level+1);
     break;
